﻿using HtmlParsingDemo.View;
using ProductDetailFetcher;
using ProductDetailFetcher.Amazon;
using System;
using System.IO;
using System.Linq;
using System.Threading.Tasks;
using System.Windows;

namespace HtmlParsingDemo
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private AmazonProductDetailsFetcher _amazonFetcher;
        
        public MainWindow()
        {
            InitializeComponent();
            _amazonFetcher = new AmazonProductDetailsFetcher();
            browser.DefaultAddress = "https://www.amazon.com/Samsung-Unlocked-Smartphone-Pro-Grade-SM-G991UZWAXAA/dp/B08N361Y2D/";
        }
          
        private async void OnUriChanged(object sender, UriChangedEventArgs e)
        {
            detailPanel.Clear();

            if(IsProductPage(e.Uri))
            {
                detailPanel.ShowLoading();
                var productDetail = await _amazonFetcher.GetProductDetailsAsync<AmazonProductDetail>(e.Uri);
                detailPanel.DisplayDetails(productDetail);
                detailPanel.HideLoading();
            }
        }

        /// <summary>
        /// Checks whether the opened page is a product page
        /// </summary>
        /// <param name="uri"></param>
        /// <returns></returns>
        private bool IsProductPage(string uri)
        {
            return uri.Contains("/dp/");
        }
    }
}
