﻿using System.Windows.Controls;
using System.Linq;
using System.Windows;
using ProductDetailFetcher.Amazon;

namespace HtmlParsingDemo.View
{
    /// <summary>
    /// Interaction logic for ProductDetailsPanel.xaml
    /// </summary>
    public partial class ProductDetailsPanel : UserControl
    {
        private const string SelectProductMessage = "Please select a Product.";
        private const string NoProductDetails = "No Product Details found.";

        public ProductDetailsPanel()
        {
            InitializeComponent();
        }

        public void DisplayDetails(AmazonProductDetail productDetail)
        {
            if (productDetail == null)
                return;

            tbName.Text = Format(productDetail.ProductName);
            tbPrice.Text = Format(productDetail.Price);
            tbAvailability.Text = Format(productDetail.Availability);
            tbManufacturer.Text = Format(productDetail.Manufacturer);
            tbRating.Text = Format(productDetail.Rating);
        }

        public void ShowLoading()
        {
            HideMessage();
            loadPanel.Visibility = Visibility.Visible;
        }

        public void HideLoading()
        {
            loadPanel.Visibility = Visibility.Collapsed;

            if(!IsAnyProductDetailVisible())
            {
                ShowMessage(NoProductDetails);
            }
        }

        public void Clear()
        {
            foreach(TextBlock tb in contentGrid.Children.OfType<TextBlock>().Where(x => Grid.GetColumn(x) == 1))
            {
                tb.Text = string.Empty;
            }
            ShowMessage(SelectProductMessage);
        }

        private void ShowMessage(string message)
        {
            tbMessage.Text = message;
            messagePanel.Visibility = Visibility.Visible;
        }

        private void HideMessage()
        {
            messagePanel.Visibility = Visibility.Collapsed;
        }

        private bool IsAnyProductDetailVisible()
        {
            return contentGrid.Children.Cast<TextBlock>().Any(x => x.Visibility == Visibility.Visible);
        }

        private string Format(string str)
        {
            if (string.IsNullOrEmpty(str))
                return str;

            return str.Replace("\n", "").Trim(' ', '.');
        }
    }
}
