﻿using System;
using System.Windows;
using System.Windows.Controls;

namespace HtmlParsingDemo.View
{
    /// <summary>
    /// Interaction logic for WebBrowser.xaml
    /// </summary>
    public partial class WebBrowser : UserControl
    {
        public string CurrentAddress => browser.Address;

        private string _defaultAddress;

        public string DefaultAddress
        {
            get => _defaultAddress;
            set => _defaultAddress = value;
        }

        public event EventHandler<UriChangedEventArgs> UriChanged;

        public WebBrowser()
        {
            InitializeComponent();
            DataContext = this;
        }

        private void OnAddressChanged(object sender, DependencyPropertyChangedEventArgs e)
        {
            if (e.OldValue == null)
            {
                RaiseUriChanged();
                return;
            }

            if (!e.NewValue.ToString().Contains(e.OldValue.ToString()))
                RaiseUriChanged();               
        }

        private void RaiseUriChanged()
        {
            UriChanged?.Invoke(this, new UriChangedEventArgs(browser.Address));
        }
    }

    public class UriChangedEventArgs : EventArgs
    {
        public string Uri { get; private set; }

        public UriChangedEventArgs(string uri)
        {
            Uri = uri;
        }
    }
}
