﻿using System;
using System.IO;
using System.Linq;
using System.Net;

namespace ProductDetailFetcher.Amazon
{
    internal static class Util
    {
        #region Public
        public static ClientConfig AmazonConfig { get; private set; }
        public static IXPathPool AmazonXPathPool { get; private set; }
        #endregion

        #region Private
        static Util()
        {
            AmazonXPathPool = new XPathPool();
            LoadStoredAmazonXPathsToPool(AmazonXPathPool);
            AmazonConfig = new ClientConfig()
            {
                BaseUri = "https://www.amazon.com",
                DecompressionMethod = DecompressionMethods.GZip
            };
        }

        private static void LoadStoredAmazonXPathsToPool(IXPathPool pool)
        {
            string[] _seperators = new string[] { "\r\n" };
            string[] data = File.ReadAllText("XPaths/AmazonXPaths.csv").Split(_seperators, StringSplitOptions.None);

            foreach (var path in data.Where(x => !x.StartsWith("*")))
            {
                if (path.Split(',').Length == 2)
                    pool.AddXPathToPool(CreateXPathObject(path));
                else
                {
                    pool.AddXPathsToPool(Enumerable.Range(1, 15).Select(x => CreateXPathObject(string.Format(path, x))));
                }
            }
        }

        private static XPathObject CreateXPathObject(string csv)
        {
            if (string.IsNullOrEmpty(csv))
                throw new ArgumentException("Invalid XPATH or Name provided.");

            string[] data = csv.Split(',');

            if (data.Length > 2)
            {
                return new XPathObject(data[0], data[1], new XPathMatchValidator(data[3], data[2].Split('|')));
            }
            else
            {
                return new XPathObject(data[0], data[1]);
            }
        }
        #endregion
    }
}
