﻿using HtmlAgilityPack;
using System.Collections.Generic;
using System.Linq;

namespace ProductDetailFetcher
{
    public class XPathMatchValidator : BaseXPathObject
    {
        /// <summary>
        /// List of words that can be found at the provided XPath
        /// </summary>
        public IEnumerable<string> ItemsSource { get; private set; }

        public XPathMatchValidator(string xPath, IEnumerable<string> itemsSource)
        {
            XPath = xPath;
            ItemsSource = itemsSource;
        }

        public XPathMatchValidator(string xPath, string validatorText)
        {
            XPath = xPath;
            ItemsSource = new List<string> { validatorText};
        }

        /// <summary>
        /// Validates whether the text present at XPath in the provided HtmlDocument matches with any of the words in the ItemsSource.
        /// </summary>
        /// <param name="doc"></param>
        /// <returns></returns>
        public bool Validate(HtmlDocument doc)
        {
            HtmlNode node = doc.DocumentNode.SelectSingleNode(XPath);

            if (node == null)
                return false;
            var innerText = node.InnerText.Trim(' ', ':');
            return ItemsSource.Contains(innerText);
        }
    }
}
