﻿using HtmlAgilityPack;
using System;
using System.Collections.Generic;
using System.Linq;

namespace ProductDetailFetcher
{
    public class XPathPool : IXPathPool
    {
        private Dictionary<string, List<XPathObject>> _xPaths;
        public XPathPool()
        {
            _xPaths = new Dictionary<string, List<XPathObject>>();
        }

        #region Public
        /// <summary>
        /// Gets the best matching XPathObjects with respect to the provided html string.
        /// </summary>
        /// <param name="html"></param>
        /// <returns></returns>
        public IEnumerable<XPathObject> GetBestMatchingXPaths(string html)
        {
            HtmlDocument doc = new HtmlDocument();
            doc.LoadHtml(html);

            foreach (var pair in _xPaths)
            {
                foreach (var xPathObj in pair.Value)
                {
                    if (!xPathObj.HasValidator && doc.IsValidXPath(xPathObj.XPath))
                    {
                        yield return xPathObj;
                        break;
                    }

                    if (xPathObj.HasValidator && xPathObj.Validator.Validate(doc))
                    {
                        yield return xPathObj;
                        break;
                    }
                }
            }

            doc.DocumentNode.ChildNodes.Clear();
        }

        /// <summary>
        /// Adds Xpath object to the pool
        /// </summary>
        /// <param name="xPathObj"></param>
        public void AddXPathToPool(XPathObject xPathObj)
        {
            if (_xPaths.ContainsKey(xPathObj.Name))
            {
                var xPaths = _xPaths[xPathObj.Name];

                if (!xPaths.Any(x => x.XPath.Equals(xPathObj)))
                    xPaths.Add(xPathObj);
            }
            else
            {
                _xPaths.Add(xPathObj.Name, new List<XPathObject>() { xPathObj });
            }
        }

        /// <summary>
        /// Adds Xpath object collection to the pool.
        /// </summary>
        /// <param name="xPathObjs"></param>
        public void AddXPathsToPool(IEnumerable<XPathObject> xPathObjs)
        {
            foreach (var xPathObj in xPathObjs)
                AddXPathToPool(xPathObj);
        }

        /// <summary>
        /// Clears the pool.
        /// </summary>
        public void Clear()
        {
            _xPaths.Clear();
        }
        #endregion
    }
}
